# Keras AdaBound

[![Travis](https://travis-ci.org/CyberZHG/keras-adabound.svg)](https://travis-ci.org/CyberZHG/keras-adabound)
[![Coverage](https://coveralls.io/repos/github/CyberZHG/keras-adabound/badge.svg?branch=master)](https://coveralls.io/github/CyberZHG/keras-adabound)

## Install

```bash
pip install keras-adabound
```

## Usage
